##  Step 3. Report and Communicate
As in the [Phase 2. Prepare the Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare?locale=en-US&state=PRODUCTION&version=CLOUD "Build high-level transformation scenarios and plan a detailed roadmap."), you will evolve your dashboards for the different stakeholder groups and leverage the preceding reports to share key insights. In addition, you can add the following KPIs and views to measure the progress of your transformation program:
![Illustrative Dashboard for Phase 4](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744b05f7a4410148ac6b575e645bbc1_LowRes.png)
Illustrative Dashboard for Phase 4
  * Integration completeness: KPI panel providing a high-level overview of the number of transformation-related Interfaces that have been implemented.
  * Application completeness: KPI panel offering a high-level overview of the number of introduced and pending Applications related to ERP transformation.


Your ERP transformation is now well covered. It is important to constantly challenge and update the plans as needed, since requirements and technical options are ever-evolving. The reported setup will help to inform these discussions by providing data-driven insights.
